phylo_vignette: A phylogenetic reconstuction to run the vignette

phylo_vignetteR Documentation

A phylogenetic reconstuction to run the vignette

Description

An example phylogeny in the right format for secsse

Usage

phylo_vignette

Format

Phylogenetic tree in phy format, rooted, including branch lengths


secsse documentation built on May 15, 2026, 5:06 p.m.