traits: A table with trait info to run the vignette

traitsR Documentation

A table with trait info to run the vignette

Description

An example of trait information in the right format for secsse

Usage

traits

Format

A data frame where each species has a trait state associated


secsse documentation built on May 15, 2026, 5:06 p.m.