- parameter
list where first vector represents lambdas, the second
mus and the third transition rates.
- phy
phylogenetic tree of class phylo, rooted and with
branch lengths. Alternatively, multiple phylogenetic trees can be provided
as the multiPhylo class.
- traits
vector with trait states for each tip in the phylogeny. The
order of the states must be the same as the tree tips. For help, see
vignette("starting_secsse", package = "secsse"). When providing a
multiPhylo set of multiple phylognies, traits should be a list where
each entry in the list corresponds to the matching phylogeny on that
position.
- num_concealed_states
number of concealed states, generally equivalent
to the number of examined states in the dataset.
- cond
condition on the existence of a node root: "maddison_cond",
"proper_cond" (default). For details, see vignette.
- root_state_weight
the method to weigh the states:
"maddison_weights", "proper_weights" (default) or "equal_weights".
It can also be specified for the root state: the vector c(1, 0, 0)
indicates state 1 was the root state. When
using a multiPhylo object, root_state_weight should be list where each
entry in the list corresponds to the root_state_weight for each tree.
- sampling_fraction
vector that states the sampling proportion per
trait state. It must have as many elements as there are trait states. When
using a multiPhylo object, sampling fraction should be list where each
entry in the list corresponds to the sampling proportion for each tree.
- setting_calculation
argument used internally to speed up calculation.
It should be left blank (default : setting_calculation = NULL).
- loglik_penalty
the size of the penalty for all parameters; default is
0 (no penalty).
- is_complete_tree
logical specifying whether or not a tree with all its
extinct species is provided. If set to TRUE, it also assumes that all
all extinct lineages are present on the tree. Defaults to FALSE.
- num_threads
number of threads to be used. Default is one thread.
- atol
A numeric specifying the absolute tolerance of integration.
- rtol
A numeric specifying the relative tolerance of integration.
- method
integration method used, available are:
"odeint::runge_kutta_cash_karp54", "odeint::runge_kutta_fehlberg78",
"odeint::runge_kutta_dopri5", "odeint::bulirsch_stoer" and
"odeint::runge_kutta4". Default method is: "odeint::bulirsch_stoer".
- num_steps
number of substeps to show intermediate likelihoods
along a branch.